==> mariadb-10.6.24.tar.gz: mariadb-10.6.24/storage/columnstore/columnstore/utils/windowfunction/wf_nth_value.h <==
/* Copyright (C) 2014 InfiniDB, Inc.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; version 2 of
   the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
   MA 02110-1301, USA. */

//  $Id: wf_nth_value.h 3868 2013-06-06 22:13:05Z xlou $

#ifndef UTILS_WF_NTH_VALUE_H
#define UTILS_WF_NTH_VALUE_H

#include "windowfunctiontype.h"

namespace windowfunction
{
template <typename T>
class WF_nth_value : public WindowFunctionType
{
 public:
  WF_nth_value(int id, const std::string& name) : WindowFunctionType(id, name)
  {
    resetData();
  }

  // pure virtual in base
  void operator()(int64_t b, int64_t e, int64_t c);
  WindowFunctionType* clone() const;
  void resetData();
  void parseParms(const std::vector<execplan::SRCP>&);

  static boost::shared_ptr<WindowFunctionType> makeFunction(int, const string&, int, WindowFunctionColumn*);

 protected:
  T fValue;
  int64_t fNth;
  bool fNthNull;
  bool fFromFirst;     // from first | from last
  bool fRespectNulls;  // respect null | ignore null
};

}  // namespace windowfunction

#endif  // UTILS_WF_NTH_VALUE_H

==> mariadb_11.8.5.orig.tar.gz: mariadb-11.8.5/storage/columnstore/columnstore/utils/windowfunction/wf_nth_value.h <==
/* Copyright (C) 2014 InfiniDB, Inc.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; version 2 of
   the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
   MA 02110-1301, USA. */

//  $Id: wf_nth_value.h 3868 2013-06-06 22:13:05Z xlou $

#pragma once

#include "windowfunctiontype.h"

namespace windowfunction
{
template <typename T>
class WF_nth_value : public WindowFunctionType
{
 public:
  WF_nth_value(int id, const std::string& name) : WindowFunctionType(id, name)
  {
    resetData();
  }

  // pure virtual in base
  void operator()(int64_t b, int64_t e, int64_t c) override;
  WindowFunctionType* clone() const override;
  void resetData() override;
  void parseParms(const std::vector<execplan::SRCP>&) override;

  static boost::shared_ptr<WindowFunctionType> makeFunction(int, const std::string&, int,
                                                            WindowFunctionColumn*);

 protected:
  T fValue;
  int64_t fNth;
  bool fNthNull;
  bool fFromFirst;     // from first | from last
  bool fRespectNulls;  // respect null | ignore null
};

}  // namespace windowfunction
